Docx Parsers
===

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_parsers

Docx to HTML
===

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_to_html

Docx to TXT
===

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_to_txt